Class: Fastlane::Helper::AppcirclePublishHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::AppcirclePublishHelper
- Defined in:
- lib/fastlane/plugin/appcircle_publish/helper/appcircle_publish_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::AppcirclePublishHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action
as Helper::AppcirclePublishHelper.your_method
11 12 13 |
# File 'lib/fastlane/plugin/appcircle_publish/helper/appcircle_publish_helper.rb', line 11 def self. UI.("Hello from the appcircle_publish plugin helper!") end |